@@ -36,6 +36,58 @@ class WXSServiceNode(AbstractNode, abc.ABC):
         for key_attr in xml_node.attributes.keys():
             if key_attr[0].lower() == 'version':
                 self._version = xml_node.get_attribute(key_attr[0])
+        self.read_version_service(xml_node)
+        if xml_node.has_child('OperationsMetadata'):
+            self.read_capabilities_operations_metadata(xml_node)
+
+    def read_version_service(self, xmlnode_tree):
+        if xmlnode_tree.has_child('ServiceIdentification'):
+            xmlnode = xmlnode_tree['ServiceIdentification']
+            if xmlnode.has_child('ServiceTypeVersion'):
+                versions = xmlnode['ServiceTypeVersion', None, :]
+                version_max = versions[0].value
+                for version_item in versions[1:]:
+                    version = version_item.value
+                    if version[0] > version_max[0]:
+                        version_max = version
+                    elif version[0] == version_max[0]:
+                        if version[2] > version_max[2]:
+                            version_max = version
+                        elif version[2] == version_max[2]:
+                            if version[4] > version_max[4]:
+                                version_max = version
+                self._version = version_max
+
+    def manage_predefined_operations_metadata(self, name, request_cap, attr):
+        return None
+
+    def read_capabilities_operations_metadata(self, xmlnode_tree):
+        for xmlnode in xmlnode_tree.children:
+
+            if xmlnode.name == 'OperationsMetadata':
+                for request_cap in xmlnode.children:
+                    for child in request_cap.children:
+                        if child.name == 'DCP':
+                            DCPType = request_cap['DCP']
+
+                    attr = {('DCP', None): DCPType}
+
+                    name = request_cap.get_attribute('name')
+                    operation = self.manage_predefined_operations_metadata(
+                        name,
+                        request_cap,
+                        attr)
+                    if operation is None:
+                        operation = WXSNodeOperation(
+                            self,
+                            name=name,
+                            namespace=request_cap.namespace_uri,
+                            attributes=attr,
+                            version=self._version)
+
+                    self._children.append(operation)
+            else:
+                self._children.append(xmlnode)
 
     def get_auth(self) -> Optional[AuthBase]:
         """
